spannertools.TrillSpanner
=========================

.. abjad-lineage:: abjad.tools.spannertools.TrillSpanner.TrillSpanner

.. autoclass:: abjad.tools.spannertools.TrillSpanner.TrillSpanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.components
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.pitch
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.written_pitch
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.__contains__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.__copy__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.__eq__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.__format__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.__getitem__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.__hash__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.__len__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.__lt__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.__ne__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.pitch
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.written_pitch
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.__hash__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.__repr__
   :noindex:
